@@ -32,7 +32,8 @@
 #include <Graph.h>
 #include <ApplicationWindow.h>
 #include <DoubleSpinBox.h>
-#include <ColorBox.h>
+#include <ColorButton.h>
+#include <PlotCurve.h>
 
 #include <QMessageBox>
 #include <QLayout>
@@ -47,6 +48,7 @@ ExpDecayDialog::ExpDecayDialog(int type, QWidget* parent, Qt::WFlags fl )
     setName( "ExpDecayDialog" );
 	setWindowTitle(tr("QtiPlot - Verify initial guesses"));
 	setSizeGripEnabled( true );
+	setAttribute(Qt::WA_DeleteOnClose);
 
 	ApplicationWindow *app = (ApplicationWindow *)parent;
 	int precision = app->fit_output_precision;
@@ -123,8 +125,8 @@ ExpDecayDialog::ExpDecayDialog(int type, QWidget* parent, Qt::WFlags fl )
 	gl1->addWidget(boxStart, 5, 1);
 
 	gl1->addWidget(new QLabel(tr("Color")), 6, 0 );
-	boxColor = new ColorBox(false);
-	boxColor->setColor(QColor(Qt::red));
+	boxColor = new ColorButton();
+	boxColor->setColor(Qt::red);
 	gl1->addWidget(boxColor, 6, 1);
 
 	gl1->setRowStretch(7, 1);
@@ -156,25 +158,24 @@ void ExpDecayDialog::setGraph(Graph *g)
 	if (!g)
 		return;
 
-    fitter = 0;
+	fitter = 0;
 	graph = g;
 
 	boxName->addItems(graph->analysableCurvesList());
 
-    QString selectedCurve = g->selectedCurveTitle();
-	if (!selectedCurve.isEmpty()){
-	    int index = boxName->findText (selectedCurve);
-		boxName->setCurrentItem(index);
-	}
-    activateCurve(boxName->currentText());
+	QString selectedCurve = g->selectedCurveTitle();
+	if (!selectedCurve.isEmpty())
+		boxName->setCurrentIndex(boxName->findText (selectedCurve));
 
-	connect (graph, SIGNAL(closedGraph()), this, SLOT(close()));
-    connect (graph, SIGNAL(dataRangeChanged()), this, SLOT(changeDataRange()));
+	activateCurve(boxName->currentText());
+
+	connect (graph, SIGNAL(destroyed()), this, SLOT(close()));
+	connect (graph, SIGNAL(dataRangeChanged()), this, SLOT(changeDataRange()));
 }
 
 void ExpDecayDialog::activateCurve(const QString& curveName)
 {
-	QwtPlotCurve *c = graph->curve(curveName);
+	PlotCurve *c = graph->curve(curveName);
 	if (!c)
 		return;
 
@@ -201,7 +202,7 @@ void ExpDecayDialog::changeDataRange()
 void ExpDecayDialog::fit()
 {
 	QString curve = boxName->currentText();
-	QwtPlotCurve *c = graph->curve(curve);
+	PlotCurve *c = graph->curve(curve);
 	QStringList curvesList = graph->analysableCurvesList();
 	if (!c || !curvesList.contains(curve)){
 		QMessageBox::critical(this,tr("QtiPlot - Warning"),
@@ -233,7 +234,7 @@ void ExpDecayDialog::fit()
 	}
 
   	if (fitter->setDataFromCurve(boxName->currentText(), boxStart->value(), c->maxXValue())){
-		fitter->setColor(boxColor->currentItem());
+		fitter->setColor(boxColor->color());
 		fitter->scaleErrors(app->fit_scale_errors);
         fitter->setOutputPrecision(app->fit_output_precision);
 		fitter->generateFunction(app->generateUniformFitPoints, app->fitPoints);
