@@ -32,6 +32,7 @@
 #include <ApplicationWindow.h>
 #include <Table.h>
 #include <Graph.h>
+#include <PlotCurve.h>
 #include <MultiLayer.h>
 #include <Matrix.h>
 #include <DoubleSpinBox.h>
@@ -52,6 +53,7 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 {
 	setWindowTitle(tr("QtiPlot - FFT Options"));
 	setSizeGripEnabled( true );
+	setAttribute(Qt::WA_DeleteOnClose);
 
     d_matrix = 0;
 	d_table = 0;
@@ -139,7 +141,7 @@ FFTDialog::FFTDialog(int type, QWidget* parent, Qt::WFlags fl )
 
 	// signals and slots connections
 	connect( buttonOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
-	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
+	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( close() ) );
 }
 
 void FFTDialog::accept()
@@ -173,6 +175,9 @@ void FFTDialog::accept()
 
 void FFTDialog::setGraph(Graph *g)
 {
+	if (!g)
+		return;
+
 	graph = g;
 	boxName->insertStringList (g->analysableCurvesList());
 	activateCurve(boxName->currentText());
@@ -181,7 +186,7 @@ void FFTDialog::setGraph(Graph *g)
 void FFTDialog::activateCurve(const QString& curveName)
 {
 	if (graph){
-		QwtPlotCurve *c = graph->curve(curveName);
+		PlotCurve *c = graph->curve(curveName);
 		if (!c)
 			return;
 
@@ -194,6 +199,9 @@ void FFTDialog::activateCurve(const QString& curveName)
 
 void FFTDialog::setTable(Table *t)
 {
+	if (!t)
+		return;
+
 	d_table = t;
 	QStringList l = t->columnsList();
 	boxName->insertStringList (l);
@@ -248,7 +256,7 @@ void FFTDialog::fftMatrix()
     Matrix *mIm = app->matrix(boxImaginary->currentText());
     if (!mIm)
         errors = true;
-    else if (mIm && mIm->numCols() != width || mIm->numRows() != height){
+    else if (mIm && (mIm->numCols() != width || mIm->numRows() != height)){
         errors = true;
         QMessageBox::warning(app, tr("QtiPlot"),
         tr("The two matrices have different dimensions, the imaginary part will be neglected!"));
