@@ -102,6 +102,7 @@ class TextEditor;
 class AssociationsDialog;
 class ScriptEdit;
 class ExportDialog;
+class Grid;
 
 /**
  * \brief QtiPlot's main window.
@@ -289,6 +290,7 @@ public slots:
 
 	//! \name Settings
 	//@{
+	void setDefaultOptions();
 	void readSettings();
 	void saveSettings();
 	void setSaveSettings(bool autoSaving, int min);
@@ -482,7 +484,7 @@ public slots:
 #endif
 
 	Table* importWaveFile();
-	void importASCII();
+	void importASCII(const QString& fileName = QString::null);
 	void importASCII(const QStringList& files, int import_mode, const QString& local_column_separator, int local_ignored_lines, bool local_rename_columns,
         bool local_strip_spaces, bool local_simplify_spaces, bool local_import_comments,
 		QLocale local_separators, const QString& local_comment_string, bool import_read_only, int endLineChar,
@@ -1099,7 +1101,6 @@ private:
 	//@{
 	void init(bool factorySettings = false);
 	void initCompleter();
-	void initGlobalConstants();
 	void createActions();
 	void initMainMenu();
 	void initToolBars();
@@ -1111,8 +1112,10 @@ private:
 	virtual QMenu * createPopupMenu(){return NULL;};
 	void updateCompleter(const QString& windowName, bool remove = false, const QString& newName = QString::null);
 	QMessageBox::StandardButton showSaveProjectMessage();
+	QString getSaveProjectName(const QString& fileName, bool *compress = 0);
 	void goToParentFolder();
 	bool isProjectFile(const QString& fn);
+	void initSearchForUpdates();
 
 private slots:
 	void disableActions();
@@ -1166,6 +1169,10 @@ private slots:
 
 // TODO: a lot of this stuff should be private
 public:
+	bool d_ask_web_connection;
+	bool d_open_last_project;
+	int d_curve_max_antialising_size;
+	bool d_disable_curve_antialiasing;
 	bool d_force_muParser;
 	bool d_keep_aspect_ration;
 	QPrinter::PaperSize d_print_paper_size;
@@ -1275,6 +1282,8 @@ public:
 	//! File version code used when opening project files (= maj * 100 + min * 10 + patch)
 	int d_file_version;
 
+	Grid *d_default_2D_grid;
+
 	QColor d_rect_default_background;
 	QBrush d_rect_default_brush;
 	QColor workspaceColor, panelsColor, panelsTextColor;
