@@ -55,6 +55,7 @@ class QTableWidget;
 class SymbolBox;
 class PatternBox;
 class PenStyleBox;
+class ApplicationWindow;
 
 //! Preferences dialog
 class ConfigDialog : public QDialog
@@ -76,6 +77,7 @@ private slots:
 
 	void accept();
 	void apply();
+	void resetDefaultSettings();
 
 	void setCurrentPage(int index);
 
@@ -134,14 +136,21 @@ private slots:
 	void loadDefaultSymbols();
 	void moveSymbol(bool up = true);
 	void moveSymbolDown(){moveSymbol(false);};
+	void showGridOptions(int axis);
+	void updateGrid();
+	void majorGridEnabled(bool);
+	void minorGridEnabled(bool);
+	void enableCurveAntialiasingSizeBox(bool);
 
 private:
+	void setApplication(ApplicationWindow *app);
 	void setSymbolsList(const QList<int>& symbList);
 	void setColorsList(const QList<QColor>& colList, const QStringList& colNames);
 	void initPlotsPage();
 	void initAppPage();
 	void initCurvesPage();
 	void initAxesPage();
+	void initGridPage();
 	void initPlots3DPage();
 	void initTablesPage();
 	void initConfirmationsPage();
@@ -150,6 +159,7 @@ private:
 	void initNotesPage();
 	void initProxyPage();
 	void initLayerGeometryPage();
+	void initLayerSpeedPage();
 	//! Calculates a sensible width for the items list
 	void updateMenuList();
 	bool validFolderPath(const QString& path);
@@ -171,7 +181,7 @@ private:
 	QPushButton* buttonTextFont, *buttonHeaderFont;
 	QStackedWidget * generalDialog;
 	QWidget *appColors, *tables, *plotOptions, *plotTicks, *plotFonts, *confirm, *plotPrint;
-	QWidget *application, *curves, *axesPage, *plots3D, *fitPage, *numericFormatPage, *notesPage, *plotGeometryPage;
+	QWidget *application, *curves, *axesPage, *plots3D, *fitPage, *numericFormatPage, *notesPage, *plotGeometryPage, *plotSpeedPage;
 	QPushButton* buttonAxesFont, *buttonNumbersFont, *buttonLegendFont, *buttonTitleFont, *fontsBtn;
 	QCheckBox *boxSearchUpdates, *boxOrthogonal, *logBox, *plotLabelBox, *scaleErrorsBox;
 	QCheckBox *boxTitle, *boxFrame, *boxPlots3D, *boxPlots2D, *boxTables, *boxNotes, *boxFolders;
@@ -199,7 +209,7 @@ private:
 	ColorButton *boxPeaksColor;
 	QLabel *lblScriptingLanguage, *lblInitWindow;
 	QComboBox *boxScriptingLanguage, *boxInitWindow;
-	QCheckBox *boxAntialiasing, *boxAutoscale3DPlots, *boxTableComments, *boxThousandsSeparator;
+	QCheckBox *boxAutoscale3DPlots, *boxTableComments, *boxThousandsSeparator;
 	QCheckBox *boxPromptRenameTables, *boxBackupProject, *boxLabelsEditing;
 	QWidget *fileLocationsPage;
 	QLabel *lblTranslationsPath, *lblHelpPath, *lblUndoStackSize, *lblEndOfLine;
@@ -282,6 +292,20 @@ private:
 	QLabel *lblAxisLabeling;
 	QComboBox *axisLabelingBox;
 	QCheckBox *boxSynchronizeScales;
+
+	QWidget *gridPage;
+	QCheckBox *boxMinorGrid, *boxMajorGrid;
+	ColorButton *boxColorMinor, *boxColorMajor;
+	PenStyleBox *boxTypeMinor, *boxTypeMajor;
+	DoubleSpinBox *boxWidthMinor, *boxWidthMajor;
+	QComboBox *boxGridYAxis, *boxGridXAxis;
+	QCheckBox *boxAntialiseGrid;
+	QListWidget *axesGridList;
+	QLabel *gridLineColorLbl, *gridLineWidthLbl, *gridLineTypeLbl, *gridAxesLbl;
+	QGroupBox * antialiasingGroupBox;
+	QCheckBox *disableAntialiasingBox, *openLastProjectBox;
+	QSpinBox *curveSizeBox;
+	QPushButton *btnDefaultSettings;
 };
 
 #endif // CONFIGDIALOG_H
