@@ -139,7 +139,7 @@ class Graph: public QwtPlot
 		enum AxisTitlePolicy{Default, ColName, ColComment, NameAndComment};
 
 		//! Returns a pointer to the parent MultiLayer object.
-		MultiLayer *multiLayer();
+		MultiLayer *multiLayer() const;
 
 		//! Change the active tool, deleting the old one if it exists.
 		void setActiveTool(PlotToolInterface *tool);
@@ -195,7 +195,7 @@ class Graph: public QwtPlot
 		QColor frameColor();
 		const QColor & paletteBackgroundColor() const;
 
-    	void print(QPainter *, const QRect &rect, const QwtPlotPrintFilter & = QwtPlotPrintFilter());
+		void print(QPainter *, const QRect &rect, const QwtPlotPrintFilter & = QwtPlotPrintFilter());
 		void updateLayout();
 		void setCanvasGeometry(const QRect &canvasRect);
 		//!Convenience function for scripts
@@ -445,7 +445,7 @@ class Graph: public QwtPlot
 
 		LegendWidget* newLegend(const QString& text = QString());
 		//! Creates a new legend text using the curves titles
-		QString legendText(bool layerSpec = false);
+		QString legendText(bool layerSpec = false, int fromIndex = 0);
 		//@}
 
 		//! \name Obsolete functions provided to keep existing Python scripts working
@@ -516,6 +516,7 @@ class Graph: public QwtPlot
 		void setTopAxisTitle(const QString& text);
 
 		QString axisTitleString(int axis);
+		void setAxisTitleString(int axis, const QString& text);
 		void setAxisTitle(int axis, const QString& text);
 		void updateAxesTitles();
 		//! TODO: eliminate this function in version 0.9.1 (used only when restoring project files)
@@ -738,6 +739,9 @@ class Graph: public QwtPlot
 		//! Enables/Disables antialiasing of plot items.
 		void setAntialiasing(bool on = true, bool update = true);
 
+		void disableCurveAntialiasing(bool disable, int maxPoints);
+		bool isCurveAntialiasingEnabled(QwtPlotItem *it);
+
 		void setCurrentFont(const QFont& f);
 		void notifyFontChange(const QFont& f){emit currentFontChanged(f);};
         void enableTextEditor();
@@ -776,7 +780,7 @@ signals:
 
 	private:
 		QString parseAxisTitle(int axis);
-		QList<FrameWidget*> stackingOrderEnrichmentsList();
+		QList<FrameWidget*> stackingOrderEnrichmentsList() const;
 		//! Finds bounding interval of the plot data.
 		QwtDoubleInterval axisBoundingInterval(int axis);
 		void deselectCurves();
@@ -808,6 +812,8 @@ signals:
 		QList<QwtPlotCurve *>d_fit_curves;
 		//! Render hint for plot items.
 		bool d_antialiasing;
+		bool d_disable_curve_antialiasing;
+		int d_max_antialising_size;
 		bool autoScaleFonts;
 		bool drawLineOn, drawArrowOn, drawAxesBackbone;
 		//! Flag telling if we are performing a print operation
