@@ -62,6 +62,7 @@ d_auto_update(false),
 d_tex_output(false)
 {
 	setAttribute(Qt::WA_DeleteOnClose);
+	setObjectName(tr("Legend"));
 
 	d_text = new QwtText(QString::null);
 	d_text->setFont(QFont("Arial", 12, QFont::Normal, false));
@@ -837,11 +838,16 @@ void LegendWidget::setAngle(int angle)
 */
 QSize LegendWidget::textSize(QPainter *p, const QwtText& text)
 {
-	QSize size = text.textSize();
-	QString s = text.text();
-	if (s.contains("<sub>") || s.contains("<sup>")){
-		int width = size.width() + QFontMetrics(text.font(), p->device()).boundingRect(" ").width();
-		size =  QSize(width, size.height());
+	QSize size = text.textSize(text.font());
+	QwtMetricsMap map;
+	map.setMetrics(this, p->device());
+	if (!map.isIdentity()){
+		QString s = text.text();
+		if (s.contains("<sub>") || s.contains("<sup>")){
+			int width = size.width() + QFontMetrics(text.font(), p->device()).boundingRect(" ").width();
+			size =  QSize(width, size.height());
+		} else
+			size = QFontMetrics(text.font(), p->device()).boundingRect(s + " ").size();
 	}
 	return size;
 }
