@@ -126,7 +126,8 @@ d_waterfall_fill_color(QColor()),
 d_canvas_size(QSize()),
 d_align_policy(AlignLayers),
 d_size_policy(UserSize),
-d_link_x_axes(false)
+d_link_x_axes(false),
+d_common_axes_layout(false)
 {
 	layerButtonsBox = new QHBoxLayout();
 	waterfallBox = new QHBoxLayout();
@@ -330,13 +331,19 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 	double w_ratio = (double)size.width()/(double)oldSize.width();
 	double h_ratio = (double)(size.height())/(double)(oldSize.height());
 
-	foreach (Graph *g, graphsList){
-		int gx = qRound(g->x()*w_ratio);
-		int gy = qRound(g->y()*h_ratio);
-		int gw = qRound(g->width()*w_ratio);
-		int gh = qRound(g->height()*h_ratio);
-		g->setGeometry(gx, gy, gw, gh);
+	if (d_common_axes_layout)
+		arrangeLayers(false, false);
+	else {
+		foreach (Graph *g, graphsList){
+			int gx = qRound(g->x()*w_ratio);
+			int gy = qRound(g->y()*h_ratio);
+			int gw = qRound(g->width()*w_ratio);
+			int gh = qRound(g->height()*h_ratio);
+			g->setGeometry(gx, gy, gw, gh);
+		}
+	}
 
+	foreach (Graph *g, graphsList){
 		if (g->autoscaleFonts())
 			g->scaleFonts(h_ratio);
 	}
@@ -660,7 +667,7 @@ void MultiLayer::setCommonLayerAxes(bool verticalAxis, bool horizontalAxis)
 			if (aux){
 				QwtScaleWidget *scale = aux->axisWidget(QwtPlot::yRight);
 				if (scale){
-					scale->setTitle(QString::null);
+					aux->setAxisTitleString(QwtPlot::yRight, QString::null);
 					QwtScaleDraw *sd = aux->axisScaleDraw(QwtPlot::yRight);
 					if (sd)
 						sd->enableComponent(QwtAbstractScaleDraw::Labels, false);
@@ -674,7 +681,7 @@ void MultiLayer::setCommonLayerAxes(bool verticalAxis, bool horizontalAxis)
 			if (aux){
 				QwtScaleWidget *scale = aux->axisWidget(QwtPlot::xBottom);
 				if (scale){
-					scale->setTitle(QString::null);
+					aux->setAxisTitleString(QwtPlot::xBottom, QString::null);
 					QwtScaleDraw *sd = aux->axisScaleDraw(QwtPlot::xBottom);
 					if (sd)
 						sd->enableComponent(QwtAbstractScaleDraw::Labels, false);
@@ -697,7 +704,7 @@ void MultiLayer::setCommonLayerAxes(bool verticalAxis, bool horizontalAxis)
 		if (verticalAxis && col){
 			QwtScaleWidget *scale = g->axisWidget(QwtPlot::yLeft);
 			if (scale){
-				scale->setTitle(QString::null);
+				g->setAxisTitleString(QwtPlot::yLeft, QString::null);
 				QwtScaleDraw *sd = g->axisScaleDraw(QwtPlot::yLeft);
 				if (sd)
 					sd->enableComponent(QwtAbstractScaleDraw::Labels, false);
@@ -707,7 +714,7 @@ void MultiLayer::setCommonLayerAxes(bool verticalAxis, bool horizontalAxis)
 		if (horizontalAxis && row){
 			QwtScaleWidget *scale = g->axisWidget(QwtPlot::xTop);
 			if (scale){
-				scale->setTitle(QString::null);
+				g->setAxisTitleString(QwtPlot::xTop, QString::null);
 				QwtScaleDraw *sd = g->axisScaleDraw(QwtPlot::xTop);
 				if (sd)
 					sd->enableComponent(QwtAbstractScaleDraw::Labels, false);
@@ -925,7 +932,7 @@ void MultiLayer::exportImage(const QString& fileName, int quality, bool transpar
 		image.save(fileName, 0, quality);
 }
 
-void MultiLayer::exportImage(QTextDocument *document, int quality, bool transparent,
+void MultiLayer::exportImage(QTextDocument *document, int, bool transparent,
 				int dpi, const QSizeF& customSize, int unit, double fontsFactor)
 {
 	if (!document)
@@ -1036,7 +1043,7 @@ void MultiLayer::exportVector(const QString& fileName, int res, bool color,
 			QRect r = g->geometry();
 			r.setSize(QSize(int(r.width()*wfactor), int(r.height()*hfactor)));
 			r.moveTo(int(r.x()*wfactor), int(r.y()*hfactor));
-        	g->print(&paint, r);
+			g->print(&paint, r);
 		}
 	} else {
     	printer.setPaperSize(QSizeF(d_canvas->width(), d_canvas->height()), QPrinter::DevicePixel);
@@ -1150,25 +1157,27 @@ void MultiLayer::copyAllLayers()
 	foreach (Graph* g, graphsList)
 		g->deselectMarker();
 
-#ifdef EMF_OUTPUT
-	if (OpenClipboard(0)){
-		EmptyClipboard();
+#ifdef Q_OS_WIN
+	#ifdef EMF_OUTPUT
+		if (OpenClipboard(0)){
+			EmptyClipboard();
 
-		QString path = QDir::tempPath();
-		QString name = path + "/" + "qtiplot_clipboard.emf";
-		name = QDir::cleanPath(name);
+			QString path = QDir::tempPath();
+			QString name = path + "/" + "qtiplot_clipboard.emf";
+			name = QDir::cleanPath(name);
 
-		exportEMF(name);
-		HENHMETAFILE handle = GetEnhMetaFile(name.toStdWString().c_str());
+			exportEMF(name);
+			HENHMETAFILE handle = GetEnhMetaFile(name.toStdWString().c_str());
 
-		SetClipboardData(CF_ENHMETAFILE, handle);
-		CloseClipboard();
-		QFile::remove(name);
-	}
+			SetClipboardData(CF_ENHMETAFILE, handle);
+			CloseClipboard();
+			QFile::remove(name);
+		}
+	#else
+		QApplication::clipboard()->setImage(canvasPixmap().convertToImage());
+	#endif
 #else
-	QPixmap pic = canvasPixmap();
-	QImage image = pic.convertToImage();
-	QApplication::clipboard()->setImage(image);
+	QApplication::clipboard()->setImage(canvasPixmap().convertToImage());
 #endif
 
 	if (selectionOn)
@@ -1343,7 +1352,7 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 		d_canvas_size = d_canvas->size();
 	} else if (e->type() == QEvent::MouseButtonPress && object == (QObject *)d_canvas){
 	    const QMouseEvent *me = (const QMouseEvent *)e;
-	    if (me->button() == Qt::RightButton)
+		if (me->button() == Qt::RightButton || me->button() == Qt::MidButton)
             return QMdiSubWindow::eventFilter(object, e);
 
 		if (d_is_waterfall_plot)
@@ -1513,6 +1522,7 @@ void MultiLayer::save(const QString &fn, const QString &geometry, bool saveAsTem
 	t << "LayerCanvasSize\t"+QString::number(l_canvas_width)+"\t"+QString::number(l_canvas_height)+"\n";
 	t << "Alignement\t"+QString::number(hor_align)+"\t"+QString::number(vert_align)+"\n";
 	t << "<AlignPolicy>" + QString::number(d_align_policy) + "</AlignPolicy>\n";
+	t << "<CommonAxes>" + QString::number(d_common_axes_layout) + "</CommonAxes>\n";
 
 	foreach (Graph *g, graphsList)
 		t << g->saveToString(saveAsTemplate);
