@@ -121,6 +121,8 @@ public:
 	void setCommonLayerAxes(bool verticalAxis = true, bool horizontalAxis = true);
 	void linkXLayerAxes(bool link = true);
 	bool hasLinkedXLayerAxes(){return d_link_x_axes;};
+	bool hasCommonAxes(){return d_common_axes_layout;};
+	void setCommonAxesLayout(bool on){d_common_axes_layout = on;};
 
 public slots:
 	Graph* addLayer(int x = 0, int y = 0, int width = 0, int height = 0, bool = false);
@@ -277,6 +279,7 @@ private:
 	AlignPolicy d_align_policy;
 	SizePolicy d_size_policy;
 	bool d_link_x_axes;
+	bool d_common_axes_layout;
 };
 
 //! Button with layer number
