@@ -676,11 +676,17 @@ void DataCurve::loadData()
 			range.from = from;
 			range.to = size - 1;
 			d_data_ranges.push_back(range);
-
 			from = size;
 		}
 	}
 
+	if (d_data_ranges.size() && from < size){
+		DataRange range;
+		range.from = from;
+		range.to = size - 1;
+		d_data_ranges.push_back(range);
+	}
+
 	X.resize(size);
 	Y.resize(size);
 
@@ -716,6 +722,8 @@ void DataCurve::loadData()
 
 	enableSpeedMode();
 
+	setRenderHint(QwtPlotItem::RenderAntialiased, g->isCurveAntialiasingEnabled(this));
+
 	if (!d_labels_list.isEmpty()){
 		((Graph*)plot())->updatePlot();
 		loadLabels();
