@@ -41,12 +41,12 @@ QwtScaleTransformation* ScaleEngine::transformation() const
 
 double ScaleTransformation::invXForm(double p, double p1, double p2, double s1, double s2) const
 {
-    if (!d_engine->hasBreak()){
-    	QwtScaleTransformation *tr = newScaleTransformation();
-        double res = tr->invXForm(p, p1, p2, s1, s2);
-        delete tr;
-        return res;
-    }
+	if (!d_engine->hasBreak()){
+		QwtScaleTransformation *tr = newScaleTransformation();
+		double res = tr->invXForm(p, p1, p2, s1, s2);
+		delete tr;
+		return res;
+	}
 
     const int d_break_space = d_engine->breakWidth();
 	const double lb = d_engine->axisBreakLeft();
@@ -103,7 +103,8 @@ double ScaleTransformation::invXForm(double p, double p1, double p2, double s1,
 
 double ScaleTransformation::xForm(double s, double s1, double s2, double p1, double p2) const
 {
-	if (d_engine->type() == ScaleTransformation::Log10 && s <= 0.0){
+	if ((d_engine->type() == ScaleTransformation::Log10 || d_engine->type() == ScaleTransformation::Ln ||
+		 d_engine->type() == ScaleTransformation::Log2) && s <= 0.0){
 		if (p1 < p2){
 			if (d_engine->testAttribute(QwtScaleEngine::Inverted))
 				return INT_MAX;
