@@ -28,6 +28,7 @@
  ***************************************************************************/
 #include "CurvesDialog.h"
 #include "QwtHistogram.h"
+#include "Spectrogram.h"
 #include <Graph.h>
 #include <Table.h>
 #include <Matrix.h>
@@ -36,6 +37,8 @@
 #include <ApplicationWindow.h>
 #include <Folder.h>
 #include <ColorBox.h>
+#include <CurveRangeDialog.h>
+#include <LegendWidget.h>
 
 #include <QPushButton>
 #include <QLabel>
@@ -48,9 +51,6 @@
 #include <QShortcut>
 #include <QKeySequence>
 #include <QMenu>
-#include <QTreeWidget>
-
-#include <QMessageBox>
 
 CurvesDialog::CurvesDialog( QWidget* parent, Qt::WFlags fl )
 : QDialog( parent, fl )
@@ -60,9 +60,9 @@ CurvesDialog::CurvesDialog( QWidget* parent, Qt::WFlags fl )
     setSizeGripEnabled(true);
 	setFocus();
 
-    QHBoxLayout *hl = new QHBoxLayout();
+	QGridLayout *hl = new QGridLayout();
 
-	hl->addWidget(new QLabel(tr("New curves style")));
+	hl->addWidget(new QLabel(tr("New curves style")), 0, 0);
 	boxStyle = new QComboBox();
 	boxStyle->addItem( QPixmap(":/lPlot.png"), tr( " Line" ) );
 	boxStyle->addItem( QPixmap(":/pPlot.png"), tr( " Scatter" ) );
@@ -75,15 +75,26 @@ CurvesDialog::CurvesDialog( QWidget* parent, Qt::WFlags fl )
 	boxStyle->addItem( QPixmap(":/vertBars.png"), tr( " Vertical Bars" ) );
 	boxStyle->addItem( QPixmap(":/hBars.png"), tr( " Horizontal Bars" ) );
 	boxStyle->addItem( QPixmap(":/histogram.png"), tr( " Histogram" ) );
-    hl->addWidget(boxStyle);
+	hl->addWidget(boxStyle, 0, 1);
 
     boxMatrixStyle = new QComboBox();
 	boxMatrixStyle->addItem( QPixmap(":/color_map.png"), tr("Contour - Color Fill"));
 	boxMatrixStyle->addItem( QPixmap(":/contour_map.png"), tr("Contour Lines"));
 	boxMatrixStyle->addItem( QPixmap(":/gray_map.png"), tr("Gray Scale Map"));
 	boxMatrixStyle->addItem( QPixmap(":/histogram.png"), tr("Histogram"));
-    hl->addWidget(boxMatrixStyle);
-    hl->addStretch();
+	hl->addWidget(boxMatrixStyle, 0, 2);
+	hl->setColumnStretch(3, 1);
+
+	hl->addWidget(new QLabel(tr("Axes")), 1, 0);
+	boxXAxis = new QComboBox();
+	boxXAxis->addItem(tr("Bottom"));
+	boxXAxis->addItem(tr("Top"));
+	hl->addWidget(boxXAxis, 1, 1);
+
+	boxYAxis = new QComboBox();
+	boxYAxis->addItem(tr("Left"));
+	boxYAxis->addItem(tr("Right"));
+	hl->addWidget(boxYAxis, 1, 2);
 
     QGridLayout *gl = new QGridLayout();
     gl->addWidget(new QLabel( tr( "Available data" )), 0, 0);
@@ -210,16 +221,16 @@ void CurvesDialog::showCurveBtn(int)
 
 void CurvesDialog::showCurveRangeDialog()
 {
-	int curve = contents->currentRow();
-	if (curve < 0)
-		curve = 0;
+	QList<QListWidgetItem *> lst = contents->selectedItems();
+	QList<int> indexes;
+	foreach(QListWidgetItem *it, lst)
+		indexes << contents->row(it);
 
-    ApplicationWindow *app = (ApplicationWindow *)this->parent();
-    if (app)
-    {
-        app->showCurveRangeDialog(d_graph, curve);
-		updateCurveRange();
-    }
+	CurveRangeDialog* crd = new CurveRangeDialog(this);
+	crd->setCurvesToModify(d_graph, indexes);
+	crd->exec();
+
+	updateCurveRange();
 }
 
 void CurvesDialog::showPlotAssociations()
@@ -337,78 +348,108 @@ void CurvesDialog::setGraph(Graph *graph)
 
 void CurvesDialog::addCurves()
 {
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+
+	QApplication::setOverrideCursor(Qt::WaitCursor);
+
+	int curves = d_graph->curveCount();
+	bool updateLegend = false;
+	LegendWidget *legend = d_graph->legend();
+	if (legend){
+		updateLegend = legend->isAutoUpdateEnabled();
+		legend->setAutoUpdate(false);
+	}
+
 	QStringList emptyColumns;
-    QList<QTreeWidgetItem *> lst = available->selectedItems ();
-    foreach (QTreeWidgetItem *item, lst){
-		if (item->type() == FolderItem)
-			continue;
-
+	QList<QTreeWidgetItem *> lst = available->selectedItems();
+	foreach (QTreeWidgetItem *item, lst){
 		QString text = item->text(0);
-		if (item->type() == TableItem){
-			ApplicationWindow *app = (ApplicationWindow *)this->parent();
-			Table *t = app->table(text);
-			if (!t)
-				continue;
+		switch(item->type()){
+			case ColumnItem:
+				if (contents->findItems(text, Qt::MatchExactly).isEmpty()){
+					Table *t = app->table(text);
+					if (t && !addCurveFromTable(app, t, text))
+						emptyColumns << text;
+				}
+			break;
 
-			QStringList lst = t->YColumns();
-			for(int i = 0; i < lst.size(); i++){
-				QString s = lst[i];
-				if (contents->findItems(s, Qt::MatchExactly ).isEmpty ()){
-					if (!addCurve(s))
-						emptyColumns << s;
+			case TableItem:{
+				Table *t = app->table(text);
+				if (!t)
+					continue;
+
+				QStringList lst = t->YColumns();
+				for(int i = 0; i < lst.size(); i++){
+					QString s = lst[i];
+					if (contents->findItems(s, Qt::MatchExactly ).isEmpty ()){
+						if (!addCurveFromTable(app, t, s))
+							emptyColumns << s;
+					}
 				}
 			}
-			continue;
-		}
+			break;
 
-        if (contents->findItems(text, Qt::MatchExactly ).isEmpty ()){
-			if (!addCurve(text))
-				emptyColumns << text;
+			case MatrixItem:
+				if (contents->findItems(text, Qt::MatchExactly).isEmpty()){
+					if (!addCurveFromMatrix(app->matrix(text), text))
+						emptyColumns << text;
+				}
+			break;
+
+			case FolderItem:
+			break;
 		}
-    }
+	}
 
 	d_graph->updateAxesTitles();
+
+	if (legend){
+		QString s = legend->text().trimmed();
+		if (!s.isEmpty())
+			s.append("\n");
+		legend->setText(s + d_graph->legendText(false, curves));
+		legend->setAutoUpdate(updateLegend);
+	}
+
 	d_graph->updatePlot();
 	Graph::showPlotErrorMessage(this, emptyColumns);
 
 	showCurveRange(boxShowRange->isChecked());
+
+	QApplication::restoreOverrideCursor();
 }
 
-bool CurvesDialog::addCurve(const QString& name)
+bool CurvesDialog::addCurveFromMatrix(Matrix *m, const QString& name)
 {
-    ApplicationWindow *app = (ApplicationWindow *)this->parent();
-    if (!app)
-        return false;
-
-    QStringList matrices = app->matrixNames();
-    if (matrices.contains(name)){
-        Matrix *m = app->matrix(name);
-        if (!m)
-            return false;
-
-        switch (boxMatrixStyle->currentIndex()){
-            case 0:
-                d_graph->plotSpectrogram(m, Graph::ColorMap);
-            break;
-            case 1:
-                d_graph->plotSpectrogram(m, Graph::Contour);
-            break;
-            case 2:
-                d_graph->plotSpectrogram(m, Graph::GrayScale);
-            break;
-			case 3:
-                d_graph->addHistogram(m);
-            break;
-        }
-
-        contents->addItem(name);
-		return true;
-    }
-
-	Table* t = app->table(name);
-	if (!t)
+	if (!m)
 		return false;
 
+	QwtPlotItem* it = NULL;
+	switch (boxMatrixStyle->currentIndex()){
+		case 0:
+			it = d_graph->plotSpectrogram(m, Graph::ColorMap);
+		break;
+		case 1:
+			it = d_graph->plotSpectrogram(m, Graph::Contour);
+		break;
+		case 2:
+			it = d_graph->plotSpectrogram(m, Graph::GrayScale);
+		break;
+		case 3:
+			it = d_graph->addHistogram(m);
+		break;
+	}
+
+	if (it)
+		it->setAxis(boxXAxis->currentIndex() + 2, boxYAxis->currentIndex());
+
+	return true;
+}
+
+bool CurvesDialog::addCurveFromTable(ApplicationWindow *app, Table *t, const QString& name)
+{
 	int style = curveStyle();
 	DataCurve *c = NULL;
 	if (style == Graph::Histogram){
@@ -424,6 +465,8 @@ bool CurvesDialog::addCurve(const QString& name)
 	if (!c)
 		return false;
 
+	c->setAxis(boxXAxis->currentIndex() + 2, boxYAxis->currentIndex());
+
 	CurveLayout cl = Graph::initCurveLayout();
 	int cIndex, sIndex;
 	d_graph->guessUniqueCurveLayout(cIndex, sIndex);
@@ -477,7 +520,6 @@ bool CurvesDialog::addCurve(const QString& name)
 		cl.connectType = 5;
 
 	d_graph->updateCurveLayout(c, &cl);
-	contents->addItem(name);
 	return true;
 }
 
@@ -556,30 +598,37 @@ int CurvesDialog::curveStyle()
 	return style;
 }
 
-void CurvesDialog::showCurveRange(bool on )
+void CurvesDialog::showCurveRange(bool on)
 {
-    int row = contents->currentRow();
-    contents->clear();
-    if (on){
-        QStringList lst = QStringList();
-        for (int i=0; i<d_graph->curveCount(); i++){
-            QwtPlotItem *it = d_graph->plotItem(i);
-            if (!it)
-                continue;
+	QList<int> selectedRows;
+	foreach(QListWidgetItem *it, contents->selectedItems())
+		selectedRows << contents->row(it);
 
-            if (it->rtti() == QwtPlotItem::Rtti_PlotCurve && ((PlotCurve *)it)->type() != Graph::Function){
-                DataCurve *c = (DataCurve *)it;
-                lst << c->title().text() + "[" + QString::number(c->startRow()+1) + ":" + QString::number(c->endRow()+1) + "]";
-            } else
-                lst << it->title().text();
-        }
-        contents->addItems(lst);
-    }
-    else
-        contents->addItems(d_graph->plotItemsList());
+	contents->clear();
+	if (on){
+		QStringList lst = QStringList();
+		for (int  i= 0; i < d_graph->curveCount(); i++){
+			QwtPlotItem *it = d_graph->plotItem(i);
+			if (!it)
+				continue;
 
-    contents->setCurrentRow(row);
-    enableContentsBtns();
+			if (it->rtti() == QwtPlotItem::Rtti_PlotCurve && ((PlotCurve *)it)->type() != Graph::Function){
+				DataCurve *c = (DataCurve *)it;
+				lst << c->title().text() + "[" + QString::number(c->startRow() + 1) + ":" + QString::number(c->endRow() + 1) + "]";
+			} else
+				lst << it->title().text();
+		}
+		contents->addItems(lst);
+	} else
+		contents->addItems(d_graph->plotItemsList());
+
+	foreach(int row, selectedRows){//restore selection
+		QListWidgetItem *it = contents->item(row);
+		if (it)
+			it->setSelected(true);
+	}
+
+	enableContentsBtns();
 }
 
 void CurvesDialog::updateCurveRange()
@@ -605,20 +654,25 @@ void CurvesDialog::showCurrentFolder(bool currentFolder)
 		addFolderItems(f);
 
 		f = f->folderBelow();
-		QTreeWidgetItem *folderItem = NULL;
-		int depth = 0;
+		TreeWidgetFolderItem *folderItem = NULL;
 		while (f){
-			if (folderItem && f->depth() > depth)
-				folderItem = new QTreeWidgetItem(folderItem, QStringList(f->objectName()), FolderItem);
-			else
-				folderItem = new QTreeWidgetItem(available, QStringList(f->objectName()), FolderItem);
+			if (f->depth() > 1){
+				Folder *parentFolder = (Folder *)f->parent();
+				QTreeWidgetItemIterator it(available);
+				 while (*it) {
+					 TreeWidgetFolderItem *fi = (TreeWidgetFolderItem *)(*it);
+					 if (fi->folder() == parentFolder){
+						 folderItem = new TreeWidgetFolderItem(fi, f);
+						 break;
+					 }
+					 ++it;
+				 }
+			} else
+				folderItem = new TreeWidgetFolderItem(available, f);
 
-			folderItem->setIcon(0, QIcon(":/folder_open.png"));
-			folderItem->setExpanded(true);
 			available->addTopLevelItem(folderItem);
-
 			addFolderItems(f, folderItem);
-			depth = f->depth();
+
 			f = f->folderBelow();
 		}
     }
@@ -689,3 +743,21 @@ void CurvesDialog::shiftCurveBy(int offset)
 	contents->addItems(d_graph->plotItemsList());
 	contents->setCurrentRow(row + offset);
 }
+
+TreeWidgetFolderItem::TreeWidgetFolderItem( QTreeWidget *parent, Folder *f )
+	: QTreeWidgetItem( parent, QStringList(f->objectName()), CurvesDialog::FolderItem)
+{
+	myFolder = f;
+
+	setIcon(0, QIcon(":/folder_open.png"));
+	setExpanded(true);
+}
+
+TreeWidgetFolderItem::TreeWidgetFolderItem( QTreeWidgetItem *parent, Folder *f )
+	: QTreeWidgetItem ( parent, QStringList(f->objectName()), CurvesDialog::FolderItem)
+{
+	myFolder = f;
+
+	setIcon(0, QIcon(":/folder_open.png"));
+	setExpanded(true);
+}
