@@ -30,15 +30,19 @@
 #define CURVESDIALOG_H
 
 #include <QDialog>
+#include <QTreeWidget>
 
 class QComboBox;
 class QListWidget;
 class QPushButton;
 class QCheckBox;
 class QTreeWidget;
-class QTreeWidgetItem;
+class TreeWidgetFolderItem;
 class Graph;
 class Folder;
+class Matrix;
+class Table;
+class ApplicationWindow;
 
 //! Add/remove curves dialog
 class CurvesDialog : public QDialog
@@ -46,6 +50,7 @@ class CurvesDialog : public QDialog
     Q_OBJECT
 
 public:
+	enum TreeItemType{FolderItem, ColumnItem, TableItem, MatrixItem};
     CurvesDialog( QWidget* parent = 0, Qt::WFlags fl = 0 );
 
 	void setGraph(Graph *graph);
@@ -67,13 +72,14 @@ private slots:
 	void shiftCurveBy(int offset = 1);
 
 private:
-	enum TreeItemType{FolderItem, ColumnItem, TableItem, MatrixItem};
-
 	void closeEvent(QCloseEvent*);
 	void addFolderItems(Folder *f, QTreeWidgetItem* parent = 0);
 
     void init();
-    bool addCurve(const QString& name);
+
+	bool addCurveFromMatrix(Matrix *m, const QString& name);
+	bool addCurveFromTable(ApplicationWindow *app, Table *t, const QString& name);
+
     QSize sizeHint() const;
     void contextMenuEvent(QContextMenuEvent *);
 
@@ -94,6 +100,26 @@ private:
 	QCheckBox* boxShowCurrentFolder;
 	QPushButton* btnUp;
 	QPushButton* btnDown;
+	QComboBox* boxXAxis;
+	QComboBox* boxYAxis;
+};
+
+/*****************************************************************************
+ *
+ * Class TreeWidgetFolderItem
+ *
+ *****************************************************************************/
+//! Folders list item class
+class TreeWidgetFolderItem : public QTreeWidgetItem
+{
+public:
+	TreeWidgetFolderItem( QTreeWidget *parent, Folder *f );
+	TreeWidgetFolderItem( QTreeWidgetItem *parent, Folder *f );
+
+	Folder *folder() { return myFolder; };
+
+protected:
+	Folder *myFolder;
 };
 
 #endif // CurvesDialog_H
