@@ -31,7 +31,7 @@
 #include "PythonSyntaxHighlighter.h"
 #include "FindReplaceDialog.h"
 #include <ApplicationWindow.h>
-#include <pixmaps.h>
+#include <MyParser.h>
 
 #include <QAction>
 #include <QMenu>
@@ -62,11 +62,21 @@ ScriptEdit::ScriptEdit(ScriptingEnv *env, QWidget *parent, const char *name)
 	setUndoRedoEnabled(true);
 	setTextFormat(Qt::PlainText);
 	setAcceptRichText (false);
+	setFocusPolicy(Qt::StrongFocus);
 
 	rehighlight();
 
 	d_fmt_default.setBackground(palette().brush(QPalette::Base));
 
+	//Init completer based on parser built-in functions
+	QStringList functions = MyParser::functionNamesList();
+	functions.sort();
+	QCompleter *completer = new QCompleter(this);
+	completer->setModelSorting(QCompleter::CaseSensitivelySortedModel);
+	completer->setCompletionMode(QCompleter::PopupCompletion);
+	completer->setModel(new QStringListModel(functions, completer));
+	setCompleter(completer);
+
 	printCursor = textCursor();
 	scriptsDirPath = qApp->applicationDirPath();
 
@@ -74,7 +84,7 @@ ScriptEdit::ScriptEdit(ScriptingEnv *env, QWidget *parent, const char *name)
 	actionExecute->setShortcut( tr("Ctrl+J") );
 	connect(actionExecute, SIGNAL(activated()), this, SLOT(execute()));
 
-	actionExecuteAll = new QAction(QIcon(QPixmap(play_xpm)), tr("Execute &All"), this);
+	actionExecuteAll = new QAction(QIcon(":/play.png"), tr("Execute &All"), this);
 	actionExecuteAll->setShortcut( tr("Ctrl+Shift+J") );
 	connect(actionExecuteAll, SIGNAL(activated()), this, SLOT(executeAll()));
 
@@ -82,39 +92,33 @@ ScriptEdit::ScriptEdit(ScriptingEnv *env, QWidget *parent, const char *name)
 	actionEval->setShortcut( tr("Ctrl+Return") );
 	connect(actionEval, SIGNAL(activated()), this, SLOT(evaluate()));
 
-	actionPrint = new QAction(QPixmap(fileprint_xpm), tr("&Print"), this);
+	actionPrint = new QAction(QIcon(":/fileprint.png"), tr("&Print"), this);
 	connect(actionPrint, SIGNAL(activated()), this, SLOT(print()));
 
-	actionImport = new QAction(QPixmap(fileopen_xpm), tr("&Import..."), this);
+	actionImport = new QAction(QIcon(":/fileopen.png"), tr("&Import..."), this);
 	actionImport->setShortcut(QKeySequence(Qt::CTRL+Qt::ALT+Qt::Key_O));
 	connect(actionImport, SIGNAL(activated()), this, SLOT(importASCII()));
 
-	QShortcut *accelImport = new QShortcut(actionImport->shortcut(), this);
-	connect(accelImport, SIGNAL(activated()), this, SLOT(importASCII()));
-
-	actionSave = new QAction(QPixmap(filesave_xpm), tr("&Save"), this);
+	actionSave = new QAction(QIcon(":/filesave.png"), tr("&Save"), this);
 	actionSave->setShortcut(QKeySequence(Qt::CTRL+Qt::ALT+Qt::Key_S));
 	connect(actionSave, SIGNAL(activated()), this, SLOT(save()));
 
-	QShortcut *accelSave = new QShortcut(actionSave->shortcut(), this);
-	connect(accelSave, SIGNAL(activated()), this, SLOT(save()));
-
-	actionExport = new QAction(QIcon(QPixmap(filesaveas_xpm)), tr("Sa&ve as..."), this);
+	actionExport = new QAction(QIcon(":/filesaveas.png"), tr("Sa&ve as..."), this);
 	connect(actionExport, SIGNAL(activated()), this, SLOT(exportASCII()));
 
-	actionFind = new QAction(QPixmap(find_xpm), tr("&Find..."), this);
+	actionFind = new QAction(QIcon(":/find.png"), tr("&Find..."), this);
 	actionFind->setShortcut(QKeySequence(Qt::CTRL+Qt::ALT+Qt::Key_F));
 	connect(actionFind, SIGNAL(activated()), this, SLOT(showFindDialog()));
 
-	actionReplace = new QAction(QPixmap(replace_xpm), tr("&Replace..."), this);
-	actionReplace->setShortcut(QKeySequence(Qt::CTRL+Qt::ALT+Qt::Key_R));
+	actionReplace = new QAction(QIcon(":/replace.png"), tr("&Replace..."), this);
+	actionReplace->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_R));
 	connect(actionReplace, SIGNAL(activated()), this, SLOT(replace()));
 
-	actionFindNext = new QAction(QPixmap(find_next_xpm), tr("&Find next"), this);
+	actionFindNext = new QAction(QIcon(":/find_next.png"), tr("&Find next"), this);
 	actionFindNext->setShortcut(QKeySequence(Qt::Key_F3));
 	connect(actionFindNext, SIGNAL(activated()), this, SLOT(findNext()));
 
-	actionFindPrevious = new QAction(QPixmap(find_previous_xpm), tr("&Find previous"), this);
+	actionFindPrevious = new QAction(QIcon(":/find_previous.png"), tr("&Find previous"), this);
 	actionFindPrevious->setShortcut(QKeySequence(Qt::Key_F4));
 	connect(actionFindPrevious, SIGNAL(activated()), this, SLOT(findPrevious()));
 
@@ -125,6 +129,30 @@ ScriptEdit::ScriptEdit(ScriptingEnv *env, QWidget *parent, const char *name)
 	connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchParentheses()));
 }
 
+void ScriptEdit::enableShortcuts()
+{
+	QShortcut *accelFindNext = new QShortcut(actionFindNext->shortcut(), this);
+	connect(accelFindNext, SIGNAL(activated()), this, SLOT(findNext()));
+
+	QShortcut *accelReplace = new QShortcut(actionReplace->shortcut(), this);
+	connect(accelReplace, SIGNAL(activated()), this, SLOT(replace()));
+
+	QShortcut *accelFindPrevious = new QShortcut(actionFindPrevious->shortcut(), this);
+	connect(accelFindPrevious, SIGNAL(activated()), this, SLOT(findPrevious()));
+
+	QShortcut *accelFind = new QShortcut(actionFind->shortcut(), this);
+	connect(accelFind, SIGNAL(activated()), this, SLOT(showFindDialog()));
+
+	QShortcut *accelSave = new QShortcut(actionSave->shortcut(), this);
+	connect(accelSave, SIGNAL(activated()), this, SLOT(save()));
+
+	QShortcut *accelImport = new QShortcut(actionImport->shortcut(), this);
+	connect(accelImport, SIGNAL(activated()), this, SLOT(importASCII()));
+
+	QShortcut *accelEval = new QShortcut(actionEval->shortcut(), this);
+	connect(accelEval, SIGNAL(activated()), this, SLOT(evaluate()));
+}
+
 void ScriptEdit::customEvent(QEvent *e)
 {
 	if (e->type() == SCRIPTING_CHANGE_EVENT)
@@ -143,12 +171,14 @@ void ScriptEdit::focusInEvent(QFocusEvent *e)
 {
      if (d_completer)
          d_completer->setWidget(this);
-     QTextEdit::focusInEvent(e);
+
+	 activated(this);
+	 return QTextEdit::focusInEvent(e);
 }
 
 void ScriptEdit::keyPressEvent(QKeyEvent *e)
 {
-    if (d_completer && d_completer->popup()->isVisible()) {
+	if (d_completer && d_completer->popup()->isVisible()){
          // The following keys are forwarded by the completer to the widget
         switch (e->key()) {
         case Qt::Key_Enter:
@@ -156,8 +186,8 @@ void ScriptEdit::keyPressEvent(QKeyEvent *e)
         case Qt::Key_Escape:
         case Qt::Key_Tab:
         case Qt::Key_Backtab:
-             e->ignore();
-             return; // let the completer do default behavior
+			e->ignore();
+			return; // let the completer do default behavior
         default:
             break;
         }
@@ -220,12 +250,12 @@ void ScriptEdit::contextMenuEvent(QContextMenuEvent *e)
 		connect(actionRenameTab, SIGNAL(activated()), sp, SLOT(renameCurrentTab()));
 		menu->addAction(actionRenameTab);
 
-		QAction *actionAddTab = new QAction(QIcon(QPixmap(plus_xpm)), tr("A&dd Tab"), menu);
+		QAction *actionAddTab = new QAction(QIcon(QPixmap(":/plus.png")), tr("A&dd Tab"), menu);
 		connect(actionAddTab, SIGNAL(activated()), sp, SLOT(addTab()));
 		menu->addAction(actionAddTab);
 
 		if (sp->tabs() > 1){
-			QAction *actionRemoveTab = new QAction(QIcon(QPixmap(delete_xpm)), tr("C&lose Tab"), menu);
+			QAction *actionRemoveTab = new QAction(QIcon(QPixmap(":/delete.png")), tr("C&lose Tab"), menu);
 			connect(actionRemoveTab, SIGNAL(activated()), sp, SLOT(removeTab()));
 			menu->addAction(actionRemoveTab);
 		}
@@ -233,13 +263,16 @@ void ScriptEdit::contextMenuEvent(QContextMenuEvent *e)
 		menu->insertSeparator();
 	}
 
+	bool python = myScript->scriptingEnv()->name() == QString("Python");
 	if (!emptyText){
-		menu->addAction(actionExecute);
-		menu->addAction(actionExecuteAll);
+		if (python){
+			menu->addAction(actionExecute);
+			menu->addAction(actionExecuteAll);
+		}
 		menu->addAction(actionEval);
 	}
 
-	if (sp){
+	if (sp && python){
 		QAction *actionAutoexec = new QAction(tr("Auto&exec"), menu);
 		actionAutoexec->setToggleAction(true);
 		actionAutoexec->setOn(sp->autoexec());
@@ -326,6 +359,30 @@ void ScriptEdit::insertFunction(const QString &fname)
 	}
 }
 
+void ScriptEdit::commentSelection()
+{
+	QTextCursor cursor = textCursor();
+	QString markedText = cursor.selectedText();
+	if (markedText.isEmpty())
+		return;
+
+	markedText.replace(QChar::ParagraphSeparator, "\n#");
+	cursor.insertText("#" + markedText);
+
+	undoAvailable(true);
+}
+
+void ScriptEdit::uncommentSelection()
+{
+	QTextCursor cursor = textCursor();
+	QString markedText = cursor.selectedText();
+	if (markedText.isEmpty() || !(markedText.contains("#") || markedText.contains("\"\"\"")))
+		return;
+
+	cursor.insertText(markedText.remove("#").remove("\"\"\""));
+	undoAvailable(true);
+}
+
 void ScriptEdit::insertFunction(QAction *action)
 {
 	insertFunction(scriptEnv->mathFunctions()[action->data().toInt()]);
@@ -397,7 +454,12 @@ void ScriptEdit::evaluate()
 
 	if (res.isValid() && !myScript->code().isEmpty())
 		if (!res.isNull() && res.canConvert(QVariant::String)){
-			QString strVal = res.toString();
+			QString strVal;
+			if (myScript->scriptingEnv()->name() == QString("Python"))
+				strVal = res.toString();
+			else
+				strVal = QLocale().toString(res.toDouble());
+
 			strVal.replace("\n", "\n#> ");
 
 			printCursor.insertText("\n");
@@ -496,19 +558,18 @@ QString ScriptEdit::exportASCII(const QString &filename)
 	QString selectedFilter;
 	QString fn;
 	if (filename.isEmpty())
-		fn = ApplicationWindow::getFileName(this, tr("Save Text to File"), scriptsDirPath, filter, &selectedFilter);
+		fn = ApplicationWindow::getFileName(this, tr("Save Text to File"), scriptsDirPath, filter, &selectedFilter, true, scriptEnv->application()->d_confirm_overwrite);
 	else
 		fn = filename;
 
 	if (!fn.isEmpty()){
 		QFileInfo fi(fn);
 		scriptsDirPath = fi.absolutePath();
-		if (!fn.endsWith(selectedFilter.remove("*"), Qt::CaseInsensitive)){
-			if (selectedFilter.contains(".txt"))
-				fn.append(".txt");
-			else if (selectedFilter.contains(".py"))
-				fn.append(".py");
-		}
+
+		if (selectedFilter.contains(".txt") && !fn.endsWith(".txt", Qt::CaseInsensitive))
+			fn.append(".txt");
+		else if (selectedFilter.contains(".py") && !fn.endsWith(".py", Qt::CaseInsensitive))
+			fn.append(".py");
 
 		QFile f(fn);
 		if (!f.open(IO_WriteOnly)){
@@ -562,30 +623,41 @@ void ScriptEdit::setDirPath(const QString& path)
 
  void ScriptEdit::setCompleter(QCompleter *completer)
  {
-     if (d_completer)
-         QObject::disconnect(d_completer, 0, this, 0);
+	 if (d_completer)
+		QObject::disconnect(d_completer, 0, this, 0);
 
-     d_completer = completer;
+	 d_completer = completer;
 
-     if (!d_completer)
-         return;
+	 if (!d_completer)
+		 return;
 
-     d_completer->setWidget(this);
-     QObject::connect(d_completer, SIGNAL(activated(const QString&)),
-                      this, SLOT(insertCompletion(const QString&)));
- }
+	 d_completer->setWidget(this);
+	 QObject::connect(d_completer, SIGNAL(activated(const QString&)), this, SLOT(insertCompletion(const QString&)));
+}
 
  void ScriptEdit::insertCompletion(const QString& completion)
  {
-     if (d_completer->widget() != this)
-         return;
+	if (!d_completer || d_completer->widget() != this)
+		return;
 
-	 QTextCursor tc = textCursor();
-     int extra = completion.length() - d_completer->completionPrefix().length();
-     tc.movePosition(QTextCursor::Left);
-     tc.movePosition(QTextCursor::EndOfWord);
-     tc.insertText(completion.right(extra));
-     setTextCursor(tc);
+	QTextCursor tc = textCursor();
+	int extra = completion.length() - d_completer->completionPrefix().length();
+	tc.movePosition(QTextCursor::Left);
+	tc.movePosition(QTextCursor::EndOfWord);
+
+	bool specialWord = (completion == "qti" || completion == "app" || completion == "self") ? true : false;
+	bool keyWord = (PythonSyntaxHighlighter::keywordsList().contains(completion));
+
+	QChar startChar = completion[0];
+	if (startChar.category() == QChar::Letter_Lowercase && !specialWord && !keyWord){
+		tc.insertText(completion.right(extra) + "()");
+		tc.movePosition(QTextCursor::PreviousCharacter, QTextCursor::MoveAnchor, 1);
+	} else if (specialWord)
+		tc.insertText(completion.right(extra) + ".");
+	else
+		tc.insertText(completion.right(extra));
+
+	setTextCursor(tc);
  }
 
  QString ScriptEdit::textUnderCursor() const
@@ -798,7 +870,8 @@ void ScriptEdit::createParenthesisSelection(int pos)
 
     QTextEdit::ExtraSelection selection;
     QTextCharFormat format = selection.format;
-    format.setBackground(Qt::green);
+	format.setBackground(Qt::green);
+	format.setForeground (Qt::red);
     selection.format = format;
 
     QTextCursor cursor = textCursor();
@@ -815,5 +888,9 @@ ScriptEdit::~ScriptEdit()
 {
 	if (d_highlighter)
 		delete d_highlighter;
+	if (d_completer){
+		d_completer->popup()->close();
+		QObject::disconnect(d_completer, 0, this, 0);
+	}
 }
 
